@@ -128,7 +128,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				      _("Name"),
 				      _("The input's name"),
 				      NULL,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READABLE));
 
 	/**
@@ -143,7 +143,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				     _("Size"),
 				     _("The input's size"),
 				     0, G_MAXINT64, 0,
-				     GSF_PARAM_STATIC |
+				     G_PARAM_STATIC_STRINGS |
 				     G_PARAM_READABLE));
 
 	/**
@@ -158,7 +158,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				       _("EOF"),
 				       _("End of file"),
 				       FALSE,
-				       GSF_PARAM_STATIC |
+				       G_PARAM_STATIC_STRINGS |
 				       G_PARAM_READABLE));
 
 	/**
@@ -173,7 +173,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				     _("Remaining"),
 				     _("Amount of data remaining"),
 				     0, G_MAXINT64, 0,
-				     GSF_PARAM_STATIC |
+				     G_PARAM_STATIC_STRINGS |
 				     G_PARAM_READABLE));
 
 	/**
@@ -188,7 +188,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				     _("Position"),
 				     _("The input's current position"),
 				     0, G_MAXINT64, 0,
-				     GSF_PARAM_STATIC |
+				     G_PARAM_STATIC_STRINGS |
 				     G_PARAM_READABLE));
 
 	/**
@@ -206,7 +206,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 		  _("Modification time"),
 		  _("An optional GDateTime representing the time the input was last changed"),
 		  G_TYPE_DATE_TIME,
-		  GSF_PARAM_STATIC |
+		  G_PARAM_STATIC_STRINGS |
 		  G_PARAM_READABLE));
 
 	/**
@@ -220,7 +220,7 @@ gsf_input_class_init (GObjectClass *gobject_class)
 				      _("Container"),
 				      _("The parent GsfInfile"),
 				      GSF_INFILE_TYPE,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READABLE));
 }
 
@@ -258,11 +258,11 @@ gsf_input_container (GsfInput *input)
 }
 
 /**
- * gsf_input_dup: (virtual Dup):
+ * gsf_input_dup: (virtual Dup)
  * @input: The input to duplicate
  * @err: (allow-none): place to store a #GError if anything goes wrong
  *
- * Duplicates input @src leaving the new one at the same offset.
+ * Duplicates @input leaving the new one at the same offset.
  *
  * Returns: (transfer full) (nullable): the duplicate
  **/
@@ -381,7 +381,7 @@ gsf_input_read (GsfInput *input, size_t num_bytes, guint8 *optional_buffer)
 }
 
 /**
- * gsf_input_read0: (rename-to gsf_input_read):
+ * gsf_input_read0: (rename-to gsf_input_read)
  * @input: the input stream
  * @num_bytes: (in): number of bytes to read
  * @bytes_read: (out): copy of @num_bytes
@@ -631,24 +631,26 @@ gboolean
 gsf_input_set_modtime_from_stat (GsfInput *input,
 				 const struct stat *st)
 {
-	GDateTime *modtime;
-	GTimeVal tv;
+	GDateTime *modtime = NULL, *ut = NULL;
 	gboolean res;
+	gint64 sec, usec;
 
 	if (st->st_mtime == (time_t)-1)
 		return FALSE;
 
-	tv.tv_sec = st->st_mtime;
+	sec = st->st_mtime;
 #if defined (HAVE_STRUCT_STAT_ST_MTIMENSEC)
-	tv.tv_usec = st->st_mtimensec / 1000;
+	usec = st->st_mtimensec / 1000;
 #elif defined (HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC)
-	tv.tv_usec =  st->st_mtim.tv_nsec / 1000;
+	usec =  st->st_mtim.tv_nsec / 1000;
 #else
-	tv.tv_usec = 0;
+	usec = 0;
 #endif
 
-	modtime = g_date_time_new_from_timeval_utc (&tv);
+	ut = g_date_time_new_from_unix_utc (sec);
+	modtime = g_date_time_add (ut, usec);
 	res = gsf_input_set_modtime (GSF_INPUT (input), modtime);
+	g_date_time_unref (ut);
 	g_date_time_unref (modtime);
 
 	return res;
