@@ -10,6 +10,7 @@
 #include <errno.h>
 
 static gboolean show_version;
+static int opt_zip64 = -1;
 
 static GOptionEntry const gsf_options [] = {
 	{
@@ -19,16 +20,19 @@ static GOptionEntry const gsf_options [] = {
 		NULL
 	},
 
+	/* All options below are for gsf testing only.  */
+	{
+		"zip64", 0,
+		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_INT, &opt_zip64,
+		"",
+		NULL
+	},
+
 	/* ---------------------------------------- */
 
 	{ NULL, 0, 0, 0, NULL, NULL, NULL}
 };
 
-typedef enum {
-	GSF_OUTFILE_TYPE_MSOLE,
-	GSF_OUTFILE_TYPE_ZIP
-} GsfOutfileType;
-
 /* ------------------------------------------------------------------------- */
 
 static GsfInfile *
@@ -51,22 +55,30 @@ open_archive (char const *filename)
 	}
 
 	infile = gsf_infile_zip_new (src, NULL);
-	if (infile)
+	if (infile) {
+		g_object_unref (src);
 		return infile;
+	}
 
 	infile = gsf_infile_msole_new (src, NULL);
-	if (infile)
+	if (infile) {
+		g_object_unref (src);
 		return infile;
+	}
 
 	infile = gsf_infile_tar_new (src, NULL);
-	if (infile)
+	if (infile) {
+		g_object_unref (src);
 		return infile;
+	}
 
 	display_name = g_filename_display_name (filename);
 	g_printerr (_("%s: Failed to recognize %s as an archive\n"),
 		    g_get_prgname (),
 		    display_name);
 	g_free (display_name);
+
+	g_object_unref (src);
 	return NULL;
 }
 
@@ -372,7 +384,7 @@ static void
 load_recursively (GsfOutfile *outfile, char const *path)
 {
 	GError *error = NULL;
-	struct stat statbuf;
+	GStatBuf statbuf;
 
 	if (g_stat (path, &statbuf) == -1) {
 		g_printerr ("Failed to stat %s: %s\n",
@@ -409,6 +421,7 @@ load_recursively (GsfOutfile *outfile, char const *path)
 		char *base;
 		GsfInput *in;
 		GsfOutput *out;
+		gboolean ok;
 
 		in = gsf_input_stdio_new (path, &error);
 		if (!in) {
@@ -422,11 +435,19 @@ load_recursively (GsfOutfile *outfile, char const *path)
 			 "modtime", gsf_input_get_modtime (in),
 			 NULL);
 		g_printerr ("Adding %s\n", path);
-		gsf_input_copy (in, out);
-		gsf_output_close (out);
+
+		ok = gsf_input_copy (in, out);
+		if (!ok)
+			g_printerr ("Error in adding member.\n");
+
+		ok = gsf_output_close (out);
+		if (!ok)
+			g_printerr ("Error in adding member (at close)\n");
+
 		g_object_unref (out);
 		g_free (base);
 
+
 		g_object_unref (in);
 	} else {
 		g_printerr ("Ignoring %s\n", path);
@@ -434,34 +455,37 @@ load_recursively (GsfOutfile *outfile, char const *path)
 }
 
 static int
-gsf_create (int argc, char **argv, GsfOutfileType type)
+gsf_create (int argc, char **argv, GType type)
 {
 	char const *filename;
 	GError *error = NULL;
 	GsfOutput *dest;
 	GsfOutfile *outfile;
 	int i;
+	gboolean ok;
 
 	if (argc < 2)
 		return 1;
 
 	filename = argv[0];
-	dest = gsf_output_stdio_new (filename, &error);
+	if (strcmp (filename, "-") == 0)
+		dest = gsf_output_stdio_new_FILE (filename, stdout, TRUE);
+	else
+		dest = gsf_output_stdio_new (filename, &error);
 	if (error) {
 		show_error (filename, error);
 		return 1;
 	}
 
-	switch (type) {
-	case GSF_OUTFILE_TYPE_MSOLE:
+	if (type == GSF_OUTFILE_MSOLE_TYPE)
 		outfile = gsf_outfile_msole_new (dest);
-		break;
-	case GSF_OUTFILE_TYPE_ZIP:
-		outfile = gsf_outfile_zip_new (dest, &error);
-		break;
-	default:
+	else if (type == GSF_OUTFILE_ZIP_TYPE) {
+		outfile = g_object_new (GSF_OUTFILE_ZIP_TYPE,
+					"sink", dest,
+					"zip64", opt_zip64,
+					NULL);
+	} else
 		g_assert_not_reached ();
-	}
 
 	if (error) {
 		show_error (filename, error);
@@ -476,7 +500,10 @@ gsf_create (int argc, char **argv, GsfOutfileType type)
 		g_object_unref (file);
 	}
 
-	gsf_output_close (GSF_OUTPUT (outfile));
+	ok = gsf_output_close (GSF_OUTPUT (outfile));
+	if (!ok)
+		g_printerr ("Error while closing archive\n");
+
 	g_object_unref (dest);
 	g_object_unref (outfile);
 	return 0;
@@ -541,9 +568,9 @@ main (int argc, char **argv)
 	if (strcmp (cmd, "listprops") == 0)
 		return gsf_list_props (argc - 2, argv + 2);
 	if (strcmp (cmd, "createole") == 0)
-		return gsf_create (argc - 2, argv + 2, GSF_OUTFILE_TYPE_MSOLE);
+		return gsf_create (argc - 2, argv + 2, GSF_OUTFILE_MSOLE_TYPE);
 	if (strcmp (cmd, "createzip") == 0)
-		return gsf_create (argc - 2, argv + 2, GSF_OUTFILE_TYPE_ZIP);
+		return gsf_create (argc - 2, argv + 2, GSF_OUTFILE_ZIP_TYPE);
 
 	g_printerr (_("Run '%s help' to see a list of subcommands.\n"), me);
 	return 1;
